@@ -1,7 +1,7 @@
 package Bencher::Scenario::PERLANCAR::state;
 
-our $DATE = '2016-03-23'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-04-13'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -78,7 +78,7 @@ Bencher::Scenario::PERLANCAR::state - Benchmark overhead of state (vs my) variab
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::PERLANCAR::state (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-03-23.
+This document describes version 0.04 of Bencher::Scenario::PERLANCAR::state (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-04-13.
 
 =head1 SYNOPSIS
 
@@ -172,22 +172,22 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m PERLANCAR::state >>):
 
  +-------------+-----------+-----------+------------+---------+---------+
  | participant | rate (/s) | time (ns) | vs_slowest | errors  | samples |
  +-------------+-----------+-----------+------------+---------+---------+
- | 10_my       | 3e+06     | 330       | 1          | 8.3e-10 | 20      |
- | 5_my        | 5.49e+06  | 182       | 1.84       | 9e-11   | 27      |
- | 10_state    | 8.22e+06  | 122       | 2.75       | 1.1e-10 | 20      |
- | 2_my        | 1.2e+07   | 83        | 4          | 1e-10   | 23      |
- | 5_state     | 1.5e+07   | 68        | 4.9        | 2.7e-10 | 20      |
- | 2_state     | 2.6e+07   | 38        | 8.8        | 4.8e-11 | 24      |
- | 1_my        | 2.96e+07  | 33.7      | 9.92       | 1.2e-11 | 20      |
- | 1_state     | 8e+07     | 10        | 3e+01      | 2e-10   | 21      |
- | baseline_0  | 9e+08     | 1         | 3e+02      | 1.1e-10 | 20      |
+ | 10_my       | 3.8e+06   | 2.6e+02   | 1          | 2.7e-10 | 27      |
+ | 5_my        | 7.7e+06   | 1.3e+02   | 2          | 2.1e-10 | 20      |
+ | 10_state    | 9.74e+06  | 103       | 2.56       | 4.6e-11 | 27      |
+ | 5_state     | 2e+07     | 51        | 5.2        | 6e-11   | 23      |
+ | 2_my        | 2.1e+07   | 48        | 5.5        | 5.3e-11 | 20      |
+ | 1_my        | 4.26e+07  | 23.5      | 11.2       | 1.2e-11 | 20      |
+ | 2_state     | 6.37e+07  | 15.7      | 16.7       | 1.1e-11 | 20      |
+ | 1_state     | 1.2e+08   | 8.1       | 33         | 1.2e-11 | 20      |
+ | baseline_0  | 7e+08     | 1         | 2e+02      | 9.1e-11 | 20      |
  +-------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
